"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.commandFactory = commandFactory;

var _fsExtra = require("fs-extra");

var _getStdin = _interopRequireDefault(require("get-stdin"));

var _executeBashCommands = require("./execute-bash-commands");

var _outputBashCommands = require("./output-bash-commands");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function commandFactory(createBashCommands) {
  return async function set(file, script) {
    if (typeof file !== 'undefined' && (await (0, _fsExtra.exists)(file)) === false) {
      return Promise.reject(new Error('File does not exist'));
    }

    try {
      const json = typeof file !== 'undefined' ? await (0, _fsExtra.readFile)(file, 'utf8') : await (0, _getStdin.default)();
      const config = JSON.parse(json);
      const bashCommands = createBashCommands(config);

      if (script) {
        (0, _outputBashCommands.outputBashCommands)(bashCommands);
        return Promise.resolve();
      }

      return (0, _executeBashCommands.executeBashCommands)(bashCommands);
    } catch (error) {
      return Promise.reject(error);
    }
  };
}