"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.set = void 0;

var _commandFactory = require("../command-factory");

var _constants = require("../constants");

var _keyboard = require("./keyboard");

var _parseConfig = require("./parse-config");

const set = (0, _commandFactory.commandFactory)(function (config) {
  const keyboardShortcuts = (0, _parseConfig.parseConfig)(config);
  const result = [];
  keyboardShortcuts.forEach(function ({
    domain,
    menu,
    shortcut
  }) {
    result.push(`defaults write ${domain} ${_constants.DEFAULTS_KEY} -dict-add "${createMenu(menu)}" "${createShortcut(shortcut)}"`);
  });
  const length = keyboardShortcuts.length;
  result.push(`echo "Set ${length} keyboard shortcut${length === 1 ? '' : 's'}"`);
  return result;
});
exports.set = set;

function createMenu(menu) {
  return menu.map(function (string) {
    return `${_keyboard.ESCAPE_KEY}${string}`;
  }).join('');
}

function createShortcut(shortcut) {
  return shortcut.map(function (keyboardKey) {
    if (keyboardKey === '') {
      return _keyboard.NULL;
    }

    const character = _keyboard.KEYBOARD_KEY_MAP[keyboardKey];
    return typeof character !== 'undefined' ? character : keyboardKey;
  }).join('');
}